==> ejc-middlemeasurement-impl-3.0.0-20221021.114700-173-sources.jar: com/ejianc/business/change/bean/ChangeVisaclaimaccountEntity.java <==
package com.ejianc.business.change.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
/**
 * 总包签证索赔台账变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_middlemeasurement_visaclaimaccount")
public class ChangeVisaclaimaccountEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="original_id")
    private Long originalId; // 原始单据id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="contract")
    private Long contract; // 合同
    @TableField(value="contract_name")
    private String contractName; // 
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="agent_id")
    private Long agentId; // 经办人
    @TableField(value="agent_name")
    private String agentName; // 经办人姓名
    @TableField(value="happen_time")
    private Date happenTime; // 发生时间
    @TableField(value="in_submit_amount_our")
    private BigDecimal inSubmitAmountOur; // 我方报送金额
    @TableField(value="in_confirm_amount_opposite")
    private BigDecimal inConfirmAmountOpposite; //  对方确认金额
    @TableField(value="in_amount_payable")
    private BigDecimal inAmountPayable; // 应付金额
    @TableField(value="in_amount_real_pay")
    private BigDecimal inAmountRealPay; // 实付金额
    @TableField(value="ex_submit_amount_our")
    private BigDecimal exSubmitAmountOur; // 我方报送金额
    @TableField(value="ex_confirm_amount_opposite")
    private BigDecimal exConfirmAmountOpposite; //  对方确认金额
    @TableField(value="ex_amount_payable")
    private BigDecimal exAmountPayable; // 应付金额
    @TableField(value="ex_amount_real_pay")
    private BigDecimal exAmountRealPay; // 实付金额
    @TableField(value="effect_date")
    private Date effectDate; // 生效时间
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changeVisaclaimaccountdetailService",pidName = "mid")//此处有pid="xxx"，默认值pid="pid"
    private List<ChangeVisaclaimaccountdetailEntity> changeVisaclaimaccountdetailEntities = new ArrayList<>(); // 总包签证索赔台账变更子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getContract() {
        return contract;
    }

    public void setContract(Long contract) {
        this.contract = contract;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public Date getHappenTime() {
        return happenTime;
    }

    public void setHappenTime(Date happenTime) {
        this.happenTime = happenTime;
    }
    public BigDecimal getInSubmitAmountOur() {
        return inSubmitAmountOur;
    }

    public void setInSubmitAmountOur(BigDecimal inSubmitAmountOur) {
        this.inSubmitAmountOur = inSubmitAmountOur;
    }
    public BigDecimal getInConfirmAmountOpposite() {
        return inConfirmAmountOpposite;
    }

    public void setInConfirmAmountOpposite(BigDecimal inConfirmAmountOpposite) {
        this.inConfirmAmountOpposite = inConfirmAmountOpposite;
    }
    public BigDecimal getInAmountPayable() {
        return inAmountPayable;
    }

    public void setInAmountPayable(BigDecimal inAmountPayable) {
        this.inAmountPayable = inAmountPayable;
    }
    public BigDecimal getInAmountRealPay() {
        return inAmountRealPay;
    }

    public void setInAmountRealPay(BigDecimal inAmountRealPay) {
        this.inAmountRealPay = inAmountRealPay;
    }
    public BigDecimal getExSubmitAmountOur() {
        return exSubmitAmountOur;
    }

    public void setExSubmitAmountOur(BigDecimal exSubmitAmountOur) {
        this.exSubmitAmountOur = exSubmitAmountOur;
    }
    public BigDecimal getExConfirmAmountOpposite() {
        return exConfirmAmountOpposite;
    }

    public void setExConfirmAmountOpposite(BigDecimal exConfirmAmountOpposite) {
        this.exConfirmAmountOpposite = exConfirmAmountOpposite;
    }
    public BigDecimal getExAmountPayable() {
        return exAmountPayable;
    }

    public void setExAmountPayable(BigDecimal exAmountPayable) {
        this.exAmountPayable = exAmountPayable;
    }
    public BigDecimal getExAmountRealPay() {
        return exAmountRealPay;
    }

    public void setExAmountRealPay(BigDecimal exAmountRealPay) {
        this.exAmountRealPay = exAmountRealPay;
    }
    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    public List<ChangeVisaclaimaccountdetailEntity> getChangeVisaclaimaccountdetailEntities() {
        return changeVisaclaimaccountdetailEntities;
    }

    public void setChangeVisaclaimaccountdetailEntities(List<ChangeVisaclaimaccountdetailEntity> changeVisaclaimaccountdetailEntities) {
        this.changeVisaclaimaccountdetailEntities = changeVisaclaimaccountdetailEntities;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/change/bean/ChangeVisaclaimaccountEntity.java <==
package com.ejianc.business.change.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
/**
 * 总包签证索赔台账变更
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_middlemeasurement_visaclaimaccount")
public class ChangeVisaclaimaccountEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="original_id")
    private Long originalId; // 原始单据id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="contract")
    private Long contract; // 合同
    @TableField(value="contract_name")
    private String contractName; // 
    @TableField(value="remarks")
    private String remarks; // 备注
    @TableField(value="agent_id")
    private Long agentId; // 经办人
    @TableField(value="agent_name")
    private String agentName; // 经办人姓名
    @TableField(value="happen_time")
    private Date happenTime; // 发生时间
    @TableField(value="in_submit_amount_our")
    private BigDecimal inSubmitAmountOur; // 我方报送金额
    @TableField(value="in_confirm_amount_opposite")
    private BigDecimal inConfirmAmountOpposite; //  对方确认金额
    @TableField(value="in_amount_payable")
    private BigDecimal inAmountPayable; // 应付金额
    @TableField(value="in_amount_real_pay")
    private BigDecimal inAmountRealPay; // 实付金额
    @TableField(value="ex_submit_amount_our")
    private BigDecimal exSubmitAmountOur; // 我方报送金额
    @TableField(value="ex_confirm_amount_opposite")
    private BigDecimal exConfirmAmountOpposite; //  对方确认金额
    @TableField(value="ex_amount_payable")
    private BigDecimal exAmountPayable; // 应付金额
    @TableField(value="ex_amount_real_pay")
    private BigDecimal exAmountRealPay; // 实付金额
    @TableField(value="effect_date")
    private Date effectDate; // 生效时间
    @TableField(value="change_reason")
    private String changeReason; // 变更原因
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="changeVisaclaimaccountdetailService",pidName = "mid")//此处有pid="xxx"，默认值pid="pid"
//    private List<ChangeVisaclaimaccountdetailEntity> changeVisaclaimaccountdetailEntities = new ArrayList<>(); // 总包签证索赔台账变更子表
    private List<ChangeVisaclaimaccountdetailEntity> visaclaimaccountdetailEntities = new ArrayList<>(); // 总包签证索赔台账变更子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getContract() {
        return contract;
    }

    public void setContract(Long contract) {
        this.contract = contract;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public Date getHappenTime() {
        return happenTime;
    }

    public void setHappenTime(Date happenTime) {
        this.happenTime = happenTime;
    }
    public BigDecimal getInSubmitAmountOur() {
        return inSubmitAmountOur;
    }

    public void setInSubmitAmountOur(BigDecimal inSubmitAmountOur) {
        this.inSubmitAmountOur = inSubmitAmountOur;
    }
    public BigDecimal getInConfirmAmountOpposite() {
        return inConfirmAmountOpposite;
    }

    public void setInConfirmAmountOpposite(BigDecimal inConfirmAmountOpposite) {
        this.inConfirmAmountOpposite = inConfirmAmountOpposite;
    }
    public BigDecimal getInAmountPayable() {
        return inAmountPayable;
    }

    public void setInAmountPayable(BigDecimal inAmountPayable) {
        this.inAmountPayable = inAmountPayable;
    }
    public BigDecimal getInAmountRealPay() {
        return inAmountRealPay;
    }

    public void setInAmountRealPay(BigDecimal inAmountRealPay) {
        this.inAmountRealPay = inAmountRealPay;
    }
    public BigDecimal getExSubmitAmountOur() {
        return exSubmitAmountOur;
    }

    public void setExSubmitAmountOur(BigDecimal exSubmitAmountOur) {
        this.exSubmitAmountOur = exSubmitAmountOur;
    }
    public BigDecimal getExConfirmAmountOpposite() {
        return exConfirmAmountOpposite;
    }

    public void setExConfirmAmountOpposite(BigDecimal exConfirmAmountOpposite) {
        this.exConfirmAmountOpposite = exConfirmAmountOpposite;
    }
    public BigDecimal getExAmountPayable() {
        return exAmountPayable;
    }

    public void setExAmountPayable(BigDecimal exAmountPayable) {
        this.exAmountPayable = exAmountPayable;
    }
    public BigDecimal getExAmountRealPay() {
        return exAmountRealPay;
    }

    public void setExAmountRealPay(BigDecimal exAmountRealPay) {
        this.exAmountRealPay = exAmountRealPay;
    }
    public Date getEffectDate() {
        return effectDate;
    }

    public void setEffectDate(Date effectDate) {
        this.effectDate = effectDate;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    public List<ChangeVisaclaimaccountdetailEntity> getVisaclaimaccountdetailEntities() {
        return visaclaimaccountdetailEntities;
    }

    public void setVisaclaimaccountdetailEntities(List<ChangeVisaclaimaccountdetailEntity> visaclaimaccountdetailEntities) {
        this.visaclaimaccountdetailEntities = visaclaimaccountdetailEntities;
    }
}
